@@ -19,12 +19,11 @@
   function(theta,
            link = "identitylink",
            earg = list(theta = theta,  # Needed
-                       inverse = FALSE,
+                       inverse = TRUE,  # 20150711: big change!!!!
                        deriv = 1,
                        short = TRUE,
                        tag = FALSE)) {
 
-
   function.name  <- link
 
   function.name2 <- attr(earg, "function.name")
@@ -34,6 +33,10 @@
 
   earg[["theta"]] <- theta  # New data
 
+  if (length(earg$inverse))
+    earg[["inverse"]] <- TRUE else
+    earg$inverse <- TRUE
+
   earg[["deriv"]] <- 1  # New
 
 
@@ -48,7 +51,7 @@
   function(theta,
            link = "identitylink",
            earg = list(theta = theta,  # Needed
-                       inverse = FALSE,
+                       inverse = TRUE,  # 20150711: big change!!!!
                        deriv = 2,
                        short = TRUE,
                        tag = FALSE)) {
@@ -62,6 +65,11 @@
 
   earg[["theta"]] <- theta  # New data
 
+
+  if (length(earg$inverse))
+    earg[["inverse"]] <- TRUE else
+    earg$inverse <- TRUE
+
   earg[["deriv"]] <- 2  # New
 
   do.call(what = function.name, args = earg)
